<?php

namespace EscapeWork\Manager\Medias\Controllers;

use EscapeWork\Manager\Http\Controllers\Controller;
use EscapeWork\Manager\Medias\Contracts\Mediable;
use EscapeWork\Manager\Medias\Http\Requests\StoreRequest;
use EscapeWork\Manager\Medias\Models\Media;
use Illuminate\Http\Request;

class MediasController extends Controller
{

    public function __construct(Mediable $model, Media $media)
    {
        parent::__construct();

        $this->model = $model;
        $this->media = $media;
    }

    public function index(Request $request)
    {
        if ($request->ajax()) {
            return $this->model->medias;
        }

        return view(config('manager-medias.views.medias.index'), [
            'config' => $request->table,
            'medias' => $this->model->medias,
            'model'  => $this->model,
            'url'    => config('manager-medias.medias.url'),
        ]);
    }

    public function store(StoreRequest $request)
    {
        return $this->model->createMultipleMedias($request->file('files'));
    }

    public function update(Request $request)
    {
        if (! $media = $this->media->findOrFail($request->id)) {
            return response([
                'error' => trans('manager-medias::controller.update.error'),
            ]);
        }

        $request->merge(['id' => $request->id]);

        $media->update($request->all());

        return response([
            'message' => trans('manager-medias::controller.update.message'),
            'id'      => $media->id
        ]);
    }

    public function destroy(Request $request)
    {
        $media = $this->media->findOrFail($request->id);

        if (! $media->delete()) {
            return redirect(route('manager.medias.index', [$request->table, $this->model->id]))
                        ->with('error', trans('manager-medias::controller.destroy.error'));
        }

        return redirect(route('manager.medias.index', [$request->table, $this->model->id]))
                    ->with('message', trans('manager-medias::controller.destroy.message'));

    }

    public function destroyAll(Request $request)
    {
        $this->model->medias->destroyAll();

        return redirect(route('manager.medias.index', [$request->table, $this->model->id]))
                    ->with('message', trans('manager-medias::controller.destroy-all.message'));
    }

}
