<?php

namespace EscapeWork\Manager\Medias\Models;

use EscapeWork\LaravelSteroids\Model;
use EscapeWork\LaravelSteroids\PresentableTrait;
use EscapeWork\Manager\Medias\Collections\MediaCollection;
use EscapeWork\Manager\Medias\Repositories\ConfigRepository;

class Media extends Model
{

    /**
     * Presentable
     */
    use PresentableTrait;

    /**
     * Presenter attribute
     */
    protected $presenter = 'EscapeWork\Manager\Medias\Presenters\MediaPresenter';

    /**
     * Table
     */
    protected $table = 'manager_medias';

    /**
     * Fillable fields
     */
    public $fillable = [
        'id',
        'media_model',
        'model_id',
        'file',
        'size',
        'caption',
        'credits',
        'order',
        'active',
        'crop_position',
    ];

    /**
     * Append fields
     */
    protected $appends = ['full_path'];

    public function scopeActive($query)
    {
        return $query->where('active', '=', true);
    }

    public function scopeGetCurrentModel($query)
    {
        return $query->where('media_model', '=', $this->media_model)
                     ->where('model_id', '=', $this->model_id);
    }

    public function scopeMediaModelFilter($query)
    {
        return $query->where('media_model', '=', $this->media_model);
    }

    public function newCollection(array $models = [])
    {
        return new MediaCollection($models);
    }

    public function delete()
    {
        $file      = config('manager-medias.medias.dir') . '/' . $this->file;
        $destroyer = app('EscapeWork\Manager\Medias\Services\MediasDestroyerService');
        $destroyer->removeMedia($file);

        return parent::delete();
    }

    public function medias()
    {
        return $this->morphTo();
    }

    public function getFullPathAttribute()
    {
        return asset(config('manager-medias.medias.url') . '/' . $this->attributes['file']);
    }

    public function getNextOrder()
    {
        $order = $this->where('media_model', '=', $this->media_model)
                            ->where('model_id', '=', $this->model_id)
                            ->orderBy('order', 'desc')
                            ->first();

        if ($order) {
            return $order->order + 1;
        }

        return 1;
    }
}
